API docs for “spamfighter.core.message.message.TaggedMessage”

# Class s.c.m.m.TaggedMessage(Message):

Part of spamfighter.core.message.message View Source View In Hierarchy

Сообщение с прицепленными к нему тэгами.

Instance Variables | _tags | список тегов, прицепленных к сообщению (type: `dict` )

Method | __init__ | Конструктор.
Method | addTag | Добавить тэг tag к сообщению.
Method | getTags | Получить все текущие тэги сообщения.
Method | checkHasAllTags | Проверить, содержит ли сообщение все указанные тэги.
Method | checkHasNoTags | Проверить, что в сообщении нет ни одного из указанных тэгов.
Method | __eq__ | Undocumented
Method | __repr__ | Undocumented

Inherited from Message:

Method | get | Получить атрибут по имени.
Method | __getitem__ | Undocumented
Method | __iter__ | Undocumented
Method | _putAttr | Добавить атрибут к сообщению.

def __init__(self, *args, **kwargs): (source)
overrides spamfighter.core.message.message.Message.__init__
Конструктор.

Для создания `TaggedMessage` из `Message` необходимо передать `Message` в параметре с именем `message`.

def addTag(self, tag): (source)
Добавить тэг tag к сообщению.

Parameters | tag | тэг (type: `str` )

def getTags(self): (source)
Получить все текущие тэги сообщения.

Returns | список тэгов (type: `list(str)` )

def checkHasAllTags(self, tags): (source)
Проверить, содержит ли сообщение все указанные тэги.

Parameters | tags | список тэгов (type: `list(str)` )
Returns | содержит ли все указанные тэги? (type: `bool` )

def checkHasNoTags(self, tags): (source)
Проверить, что в сообщении нет ни одного из указанных тэгов.

Parameters | tags | список тэгов (type: `list(str)` )
Returns | не содержит ли все указанные тэги? (type: `bool` )

def __eq__(self, other): (source)
overrides spamfighter.core.message.message.Message.__eq__
Undocumented
def __repr__(self): (source)
overrides spamfighter.core.message.message.Message.__repr__
Undocumented